@@ -52,8 +52,8 @@ class Benno
      */
     function __construct()
     {
-        $this->infoText = 'Benno MailArchiv Version 2.8.21-1'; 
-        $this->buildInfo= '230306163716/8ad051e';
+        $this->infoText = 'Benno MailArchiv Version 2.10.0'; 
+        $this->buildInfo= '230413141016/e59a21f';
         $this->buildYear= '2023';
     }
 
