@@ -356,6 +356,9 @@ class Query
         if ($participant == '') { return ''; }
 
         global $App;
+        //$or    = ' OR ';  // necessary??
+
+        $sender_query = '';
         $sender_q = $participant.'*';
         if (!$App->getConfig('SUPPRESS_LEADING_WILDCARD')) {
             $sender_q = '*'.$participant.'*';
@@ -376,6 +379,9 @@ class Query
         if ($participant == '') { return ''; }
 
         global $App;
+        //$or    = ' OR ';  // necessary??
+
+        $recipient_query = '';
         $recipient_q = $participant.'*';
         if (!$App->getConfig('SUPPRESS_LEADING_WILDCARD')) {
             $recipient_q = '*'.$participant.'*';
